@@ -25,17 +25,17 @@
     <message>
         <location filename="src/AboutView.cpp" line="31"/>
         <source>You may want to try my other apps as well:</source>
-        <translation type="unfinished"/>
+        <translation>Спробуйте інші мої програми:</translation>
     </message>
     <message>
         <location filename="src/AboutView.cpp" line="34"/>
         <source>%1, a YouTube music player</source>
-        <translation type="unfinished"/>
+        <translation>%1, музичний плеєр YouTube</translation>
     </message>
     <message>
         <location filename="src/AboutView.cpp" line="38"/>
         <source>%1, a music player</source>
-        <translation type="unfinished"/>
+        <translation>%1, музичний плеєр</translation>
     </message>
     <message>
         <location filename="src/AboutView.cpp" line="44"/>
@@ -43,42 +43,27 @@
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/AboutView.cpp" line="48"/>
-        <source>Report bugs and send in your ideas to %1</source>
-        <translation>Повідомляйте про помилки та пропонуйте свої ідеї на %1</translation>
-    </message>
-    <message>
-        <location filename="src/AboutView.cpp" line="52"/>
+        <location filename="src/AboutView.cpp" line="49"/>
         <source>Icon designed by %1.</source>
         <translation>Піктограму намалював %1.</translation>
     </message>
     <message>
         <location filename="src/AboutView.cpp" line="53"/>
-        <source>Compact mode contributed by %1.</source>
-        <translation>Компактний режим розробив %1.</translation>
-    </message>
-    <message>
-        <location filename="src/AboutView.cpp" line="54"/>
-        <source>HTTP proxy support contributed by %1.</source>
-        <translation>Підтримку HTTP-проксі розробив %1.</translation>
-    </message>
-    <message>
-        <location filename="src/AboutView.cpp" line="58"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
         <translation>Ліцензовано &lt;a href=&apos;%1&apos;&gt;Загальною громадською ліцензією GNU&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="src/AboutView.cpp" line="70"/>
+        <location filename="src/AboutView.cpp" line="65"/>
         <source>&amp;Close</source>
         <translation>&amp;Закрити</translation>
     </message>
     <message>
-        <location filename="src/AboutView.h" line="18"/>
+        <location filename="src/AboutView.h" line="25"/>
         <source>About</source>
         <translation>Про програму</translation>
     </message>
     <message>
-        <location filename="src/AboutView.h" line="20"/>
+        <location filename="src/AboutView.h" line="27"/>
         <source>What you always wanted to know about %1 and never dared to ask</source>
         <translation>Все те, про %1, що ви завжди хотіли дізнатись, але не наважувалися спитати</translation>
     </message>
@@ -96,12 +81,12 @@
     <message>
         <location filename="local/src/demostartupview.cpp" line="35"/>
         <source>Please license %1</source>
-        <translation type="unfinished"/>
+        <translation>Ліцензія %1</translation>
     </message>
     <message>
         <location filename="local/src/demostartupview.cpp" line="39"/>
         <source>This demo has expired.</source>
-        <translation type="unfinished"/>
+        <translation>Пробний період вичерпано.</translation>
     </message>
     <message>
         <location filename="local/src/demostartupview.cpp" line="41"/>
@@ -111,7 +96,7 @@
     <message>
         <location filename="local/src/demostartupview.cpp" line="43"/>
         <source>This demo will expire in %1 days.</source>
-        <translation type="unfinished"/>
+        <translation>Пробний період завершиться за %1 днів.</translation>
     </message>
     <message>
         <location filename="local/src/demostartupview.cpp" line="45"/>
@@ -121,58 +106,58 @@
     <message>
         <location filename="local/src/demostartupview.cpp" line="57"/>
         <source>Use Demo</source>
-        <translation type="unfinished"/>
+        <translation>Пробна версія</translation>
     </message>
     <message>
         <location filename="local/src/demostartupview.cpp" line="65"/>
         <source>Get the full version</source>
-        <translation type="unfinished"/>
+        <translation>Отримати повну версію</translation>
     </message>
 </context>
 <context>
     <name>DownloadItem</name>
     <message>
-        <location filename="src/downloaditem.cpp" line="299"/>
+        <location filename="src/downloaditem.cpp" line="308"/>
         <source>bytes</source>
         <translation>байт</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="302"/>
+        <location filename="src/downloaditem.cpp" line="311"/>
         <source>KB</source>
         <translation>КБ</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="305"/>
+        <location filename="src/downloaditem.cpp" line="314"/>
         <source>MB</source>
         <translation>МБ</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="321"/>
+        <location filename="src/downloaditem.cpp" line="330"/>
         <source>bytes/sec</source>
         <translation>байт/сек</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="324"/>
+        <location filename="src/downloaditem.cpp" line="333"/>
         <source>KB/sec</source>
         <translation>КБ/сек</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="327"/>
+        <location filename="src/downloaditem.cpp" line="336"/>
         <source>MB/sec</source>
         <translation>МБ/сек</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="333"/>
+        <location filename="src/downloaditem.cpp" line="342"/>
         <source>seconds</source>
         <translation>секунд</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="336"/>
+        <location filename="src/downloaditem.cpp" line="345"/>
         <source>minutes</source>
         <translation>хвилин</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="339"/>
+        <location filename="src/downloaditem.cpp" line="348"/>
         <source>%4 %5 remaining</source>
         <translation>залишилось %4 %5</translation>
     </message>
@@ -308,22 +293,22 @@
 <context>
     <name>ListModel</name>
     <message>
-        <location filename="src/ListModel.cpp" line="47"/>
+        <location filename="src/ListModel.cpp" line="51"/>
         <source>Searching...</source>
         <translation>Йде пошук…</translation>
     </message>
     <message>
-        <location filename="src/ListModel.cpp" line="48"/>
+        <location filename="src/ListModel.cpp" line="52"/>
         <source>Show %1 More</source>
         <translation>Показати ще %1</translation>
     </message>
     <message>
-        <location filename="src/ListModel.cpp" line="49"/>
+        <location filename="src/ListModel.cpp" line="53"/>
         <source>No videos</source>
         <translation>Нема відео</translation>
     </message>
     <message>
-        <location filename="src/ListModel.cpp" line="50"/>
+        <location filename="src/ListModel.cpp" line="54"/>
         <source>No more videos</source>
         <translation>Більше немає відео</translation>
     </message>
@@ -339,453 +324,492 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="src/MainWindow.cpp" line="125"/>
+        <location filename="src/MainWindow.cpp" line="160"/>
         <source>&amp;Stop</source>
         <translation>&amp;Зупинити</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="126"/>
+        <location filename="src/MainWindow.cpp" line="161"/>
         <source>Stop playback and go back to the search view</source>
         <translation>Зупинити відтворення та повернутися до вікна пошуку</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="132"/>
+        <location filename="src/MainWindow.cpp" line="179"/>
         <source>S&amp;kip</source>
         <translation>П&amp;ропустити</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="133"/>
+        <location filename="src/MainWindow.cpp" line="180"/>
         <source>Skip to the next video</source>
         <translation>Перейти до наступного відео</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="139"/>
-        <location filename="src/MainWindow.cpp" line="740"/>
+        <location filename="src/MainWindow.cpp" line="186"/>
+        <location filename="src/MainWindow.cpp" line="835"/>
         <source>&amp;Pause</source>
         <translation>&amp;Пауза</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="140"/>
-        <location filename="src/MainWindow.cpp" line="741"/>
+        <location filename="src/MainWindow.cpp" line="187"/>
+        <location filename="src/MainWindow.cpp" line="836"/>
         <source>Pause playback</source>
         <translation>Призупинити відтворення</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="146"/>
+        <location filename="src/MainWindow.cpp" line="193"/>
         <source>&amp;Full Screen</source>
         <translation>Н&amp;а весь екран</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="147"/>
+        <location filename="src/MainWindow.cpp" line="194"/>
         <source>Go full screen</source>
         <translation>Переключити на повноекранний режим</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="162"/>
-        <source>&amp;Compact mode</source>
-        <translation>&amp;Компактний режим</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="163"/>
+        <location filename="src/MainWindow.cpp" line="210"/>
         <source>Hide the playlist and the toolbar</source>
         <translation>Сховати плейлист і панель інструментів</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="171"/>
-        <source>Open the &amp;YouTube page</source>
-        <translation>Відкрити сторінку на &amp;YouTube</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="172"/>
+        <location filename="src/MainWindow.cpp" line="223"/>
         <source>Go to the YouTube video page and pause playback</source>
         <translation>Відкрити сторінку на YouTube та призупинити відтворення</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="178"/>
-        <source>Copy the YouTube &amp;link</source>
-        <translation>Скопіювати YouTube-по&amp;силання</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="179"/>
+        <location filename="src/MainWindow.cpp" line="230"/>
         <source>Copy the current video YouTube link to the clipboard</source>
         <translation>Скопіювати YouTube-посилання поточного відео в буфер</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="185"/>
-        <source>Copy the video stream &amp;URL</source>
-        <translation>Скопіювати URL ві&amp;деопотоку</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="186"/>
+        <location filename="src/MainWindow.cpp" line="237"/>
         <source>Copy the current video stream URL to the clipboard</source>
         <translation>Скопіювати URL поточного відеопотоку в буфер</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="192"/>
-        <source>Find video &amp;parts</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="193"/>
+        <location filename="src/MainWindow.cpp" line="244"/>
         <source>Find other video parts hopefully in the right order</source>
-        <translation type="unfinished"/>
+        <translation>Знайти інші частини відео</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="199"/>
+        <location filename="src/MainWindow.cpp" line="250"/>
         <source>&amp;Remove</source>
         <translation>&amp;Вилучити</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="200"/>
+        <location filename="src/MainWindow.cpp" line="251"/>
         <source>Remove the selected videos from the playlist</source>
         <translation>Вилучити вибрані відео з плейлисту</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="206"/>
+        <location filename="src/MainWindow.cpp" line="257"/>
         <source>Move &amp;Up</source>
         <translation>Зсув в&amp;гору</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="207"/>
+        <location filename="src/MainWindow.cpp" line="258"/>
         <source>Move up the selected videos in the playlist</source>
         <translation>Зсунути вибрані в плейлисті відео вгору</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="213"/>
+        <location filename="src/MainWindow.cpp" line="264"/>
         <source>Move &amp;Down</source>
         <translation>Зсунути вни&amp;з</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="214"/>
+        <location filename="src/MainWindow.cpp" line="265"/>
         <source>Move down the selected videos in the playlist</source>
         <translation>Зсунути вибрані в плейлисті відео вниз</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="220"/>
-        <source>&amp;Clear recent searches</source>
-        <translation>&amp;Очистити історію недавніх пошуків</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="225"/>
+        <location filename="src/MainWindow.cpp" line="276"/>
         <source>Clear the search history. Cannot be undone.</source>
         <translation>Очистити історію пошуку. Зміни необоротні.</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="230"/>
+        <location filename="src/MainWindow.cpp" line="281"/>
         <source>&amp;Quit</source>
         <translation>Ви&amp;хід</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="232"/>
-        <source>Ctrl+Q</source>
-        <translation>Ctrl+Q</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="233"/>
+        <location filename="src/MainWindow.cpp" line="284"/>
         <source>Bye</source>
         <translation>До побачення</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="237"/>
+        <location filename="src/MainWindow.cpp" line="288"/>
         <source>&amp;Website</source>
         <translation>Са&amp;йт</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="239"/>
+        <location filename="src/MainWindow.cpp" line="290"/>
         <source>%1 on the Web</source>
         <translation>%1 в вебі</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="244"/>
-        <source>Make a &amp;donation</source>
-        <translation>Підтримати про&amp;ект</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="245"/>
+        <location filename="src/MainWindow.cpp" line="296"/>
         <source>Please support the continued development of %1</source>
         <translation>Будь ласка, підтримайте подальший розвиток %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="250"/>
+        <location filename="src/MainWindow.cpp" line="301"/>
         <source>&amp;About</source>
         <translation>&amp;Про програму</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="252"/>
+        <location filename="src/MainWindow.cpp" line="303"/>
         <source>Info about %1</source>
         <translation>Інформація про %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="260"/>
+        <location filename="src/MainWindow.cpp" line="311"/>
         <source>Search</source>
         <translation>Пошук</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="279"/>
+        <location filename="src/MainWindow.cpp" line="330"/>
         <source>Mute volume</source>
         <translation>Приглушити гучність</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="281"/>
-        <source>Ctrl+M</source>
-        <translation>Ctrl+M</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="312"/>
-        <location filename="src/MainWindow.cpp" line="1091"/>
+        <location filename="src/MainWindow.cpp" line="359"/>
+        <location filename="src/MainWindow.cpp" line="1179"/>
         <source>&amp;Downloads</source>
         <translation>&amp;Завантаження</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="313"/>
+        <location filename="src/MainWindow.cpp" line="360"/>
         <source>Show details about video downloads</source>
         <translation>Показати подробиці про завантажувані відео</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="321"/>
+        <location filename="src/MainWindow.cpp" line="368"/>
         <source>&amp;Download</source>
         <translation>&amp;Завантажити</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="322"/>
+        <location filename="src/MainWindow.cpp" line="369"/>
         <source>Download the current video</source>
         <translation>Завантажити поточне відео</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="334"/>
+        <location filename="src/MainWindow.cpp" line="381"/>
         <source>Share the current video using %1</source>
-        <translation type="unfinished"/>
+        <translation>Поділитись відео через %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="346"/>
+        <location filename="src/MainWindow.cpp" line="393"/>
         <source>&amp;Email</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Email</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="347"/>
+        <location filename="src/MainWindow.cpp" line="394"/>
         <source>Email</source>
-        <translation type="unfinished"/>
+        <translation>Email</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="382"/>
+        <location filename="src/MainWindow.cpp" line="398"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Закрити</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="403"/>
+        <source>&amp;Float on Top</source>
+        <translation>&amp;Поверх всіх вікон</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="408"/>
+        <source>&amp;Stop After This Video</source>
+        <translation>&amp;Зупинити після цього відео</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="445"/>
         <source>&amp;Application</source>
         <translation>&amp;Програма</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="390"/>
-        <source>&amp;Playback</source>
-        <translation type="unfinished"/>
+        <location filename="src/MainWindow.cpp" line="447"/>
+        <source>Buy %1...</source>
+        <translation>Придбати %1...</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="400"/>
+        <location filename="src/MainWindow.cpp" line="458"/>
+        <source>&amp;Playback</source>
+        <translation>&amp;Відтворення</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="472"/>
         <source>&amp;Playlist</source>
         <translation>&amp;Плейлист</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="407"/>
+        <location filename="src/MainWindow.cpp" line="479"/>
         <source>&amp;Video</source>
         <translation>В&amp;ідео</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="421"/>
+        <location filename="src/MainWindow.cpp" line="490"/>
         <source>&amp;View</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Вигляд</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="427"/>
+        <location filename="src/MainWindow.cpp" line="497"/>
         <source>&amp;Share</source>
-        <translation type="unfinished"/>
+        <translation>&amp;Поділитись</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="435"/>
+        <location filename="src/MainWindow.cpp" line="509"/>
         <source>&amp;Help</source>
         <translation>&amp;Довідка</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="520"/>
+        <location filename="src/MainWindow.cpp" line="586"/>
         <source>Press %1 to raise the volume, %2 to lower it</source>
         <translation>Натисніть %1, щоб збільшити гучність, а %2 — щоб знизити</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="669"/>
-        <location filename="src/MainWindow.cpp" line="675"/>
+        <location filename="src/MainWindow.cpp" line="748"/>
+        <location filename="src/MainWindow.cpp" line="754"/>
         <source>Opening %1</source>
         <translation>Відкриття %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="688"/>
+        <location filename="src/MainWindow.cpp" line="787"/>
         <source>Do you want to exit %1 with a download in progress?</source>
         <translation>Триває завантаження відео. Ви бажаєте закрити %1?</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="689"/>
+        <location filename="src/MainWindow.cpp" line="788"/>
         <source>If you close %1 now, this download will be cancelled.</source>
         <translation>Якщо ви закриєте %1 прямо зараз, ці завантаження будуть скасовані.</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="692"/>
+        <location filename="src/MainWindow.cpp" line="793"/>
         <source>Close and cancel download</source>
         <translation>Закрити та скасувати завантаження</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="693"/>
+        <location filename="src/MainWindow.cpp" line="794"/>
         <source>Wait for download to finish</source>
         <translation>Дочекатися завершення завантаження</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="854"/>
+        <location filename="src/MainWindow.cpp" line="940"/>
         <source>Leave &amp;Full Screen</source>
-        <translation type="unfinished"/>
+        <translation>Вийти з &amp;Повноекранного режиму</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1195"/>
+        <location filename="src/MainWindow.cpp" line="1283"/>
         <source>%1 version %2 is now available.</source>
-        <translation type="unfinished"/>
+        <translation>%1 версія %2 доступна.</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1201"/>
+        <location filename="src/MainWindow.cpp" line="1297"/>
         <source>Remind me later</source>
-        <translation type="unfinished"/>
+        <translation>Нагадати мені пізніше</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1207"/>
-        <location filename="src/MainWindow.cpp" line="1213"/>
+        <location filename="src/MainWindow.cpp" line="1294"/>
         <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1216"/>
+        <location filename="src/MainWindow.cpp" line="1301"/>
         <source>Update</source>
-        <translation type="unfinished"/>
+        <translation>Оновлення</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="733"/>
+        <location filename="src/MainWindow.cpp" line="828"/>
         <source>Error: %1</source>
         <translation>Помилка: %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="756"/>
+        <location filename="src/MainWindow.cpp" line="169"/>
+        <source>P&amp;revious</source>
+        <translation>П&amp;опередній</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="170"/>
+        <source>Go back to the previous track</source>
+        <translation>Повернутись до попереднього треку</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="209"/>
+        <source>&amp;Compact Mode</source>
+        <translation>&amp;Компактний режим</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="222"/>
+        <source>Open the &amp;YouTube Page</source>
+        <translation>Відкрити сторінку &amp;YouTube</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="229"/>
+        <source>Copy the YouTube &amp;Link</source>
+        <translation>Ві&amp;дкрити сторінку YouTube</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="236"/>
+        <source>Copy the Video Stream &amp;URL</source>
+        <translation>Копіювати посилання &amp;на відеопотік</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="243"/>
+        <source>Find Video &amp;Parts</source>
+        <translation>Знайти &amp;Відеофрагменти</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="271"/>
+        <source>&amp;Clear Recent Searches</source>
+        <translation>&amp;Очистити попередній пошук</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="295"/>
+        <source>Make a &amp;Donation</source>
+        <translation>Зробити &amp;Пожертву</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="352"/>
+        <source>&amp;Manually Start Playing</source>
+        <translation>&amp;Починати програвання вручну</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="353"/>
+        <source>Manually start playing videos</source>
+        <translation>Manually start playing videos</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="848"/>
         <source>&amp;Play</source>
         <translation>Гр&amp;ати</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="757"/>
+        <location filename="src/MainWindow.cpp" line="849"/>
         <source>Resume playback</source>
         <translation>Відновити відтворення</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="964"/>
+        <location filename="src/MainWindow.cpp" line="1055"/>
         <source>Remaining time: %1</source>
         <translation>Залишилось часу: %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1022"/>
+        <location filename="src/MainWindow.cpp" line="1113"/>
         <source>Volume at %1%</source>
         <translation>Гучність %1%</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1028"/>
+        <location filename="src/MainWindow.cpp" line="1119"/>
         <source>Volume is muted</source>
         <translation>Гучність приглушено</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1031"/>
+        <location filename="src/MainWindow.cpp" line="1122"/>
         <source>Volume is unmuted</source>
         <translation>Гучність відновлено</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1038"/>
+        <location filename="src/MainWindow.cpp" line="1129"/>
         <source>Maximum video definition set to %1</source>
         <translation>Максимальна чіткість відео встановлена на %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1076"/>
+        <location filename="src/MainWindow.cpp" line="1165"/>
         <source>Your privacy is now safe</source>
         <translation>Ваша конфіденційність зараз у безпеці</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1092"/>
+        <location filename="src/MainWindow.cpp" line="1180"/>
         <source>Downloads complete</source>
         <translation>Завантаження завершено</translation>
     </message>
+    <message>
+        <location filename="local/mac/macsupport.cpp" line="58"/>
+        <source>&amp;Window</source>
+        <translation>&amp;Вікно</translation>
+    </message>
+    <message>
+        <location filename="local/mac/macsupport.cpp" line="61"/>
+        <source>&amp;Minimize</source>
+        <translation>&amp;Звернути</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
     <message>
-        <location filename="src/MediaView.cpp" line="33"/>
+        <location filename="src/MediaView.cpp" line="35"/>
         <source>Most relevant</source>
         <translation>Подібні</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="40"/>
+        <location filename="src/MediaView.cpp" line="42"/>
         <source>Most recent</source>
         <translation>Недавні</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="47"/>
+        <location filename="src/MediaView.cpp" line="49"/>
         <source>Most viewed</source>
         <translation>Популярні</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="526"/>
+        <location filename="src/MediaView.cpp" line="521"/>
         <source>You can now paste the YouTube link into another application</source>
         <translation>Тепер ви можете вставити це посилання до іншої програми</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="534"/>
+        <location filename="src/MediaView.cpp" line="529"/>
         <source>You can now paste the video stream URL into another application</source>
         <translation>Тепер ви можете вставити URL відеопотоку до іншої програми</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="535"/>
+        <location filename="src/MediaView.cpp" line="530"/>
         <source>The link will be valid only for a limited time.</source>
         <translation>Посилання буде дійсне тільки протягом обмеженого часу.</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="634"/>
+        <location filename="src/MediaView.cpp" line="629"/>
         <source>This is just the demo version of %1.</source>
         <translation>Це всього лише демо-версія %1.</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="635"/>
+        <location filename="src/MediaView.cpp" line="630"/>
         <source>It allows you to test the application and see if it works for you.</source>
         <translation>Ви маете змогу протеступати програму та перевірити її працездатність.</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="665"/>
+        <location filename="src/MediaView.cpp" line="660"/>
         <source>Continue</source>
         <translation>Продовжити</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="754"/>
+        <location filename="src/MediaView.cpp" line="749"/>
         <source>of</source>
         <comment>Used in video parts, as in '2 of 3'</comment>
-        <translation type="unfinished"/>
+        <translation>з</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="766"/>
+        <location filename="src/MediaView.cpp" line="761"/>
         <source>part</source>
         <comment>This is for video parts, as in 'Cool video - part 1'</comment>
-        <translation type="unfinished"/>
+        <translation>частина</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="768"/>
+        <location filename="src/MediaView.cpp" line="763"/>
         <source>episode</source>
         <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
-        <translation type="unfinished"/>
+        <translation>епізод</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="826"/>
+        <location filename="src/MediaView.cpp" line="821"/>
         <source>Sent from %1</source>
-        <translation type="unfinished"/>
+        <translation>Відправити з %1</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="642"/>
+        <location filename="src/MediaView.cpp" line="637"/>
         <source>Get the full version</source>
         <translation>Отримати повнофункціональну версію</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="687"/>
+        <location filename="src/MediaView.cpp" line="682"/>
         <source>Downloading %1</source>
         <translation>Завантаження %1</translation>
     </message>
@@ -801,7 +825,7 @@
 <context>
     <name>PrettyItemDelegate</name>
     <message>
-        <location filename="src/playlist/PrettyItemDelegate.cpp" line="156"/>
+        <location filename="src/playlist/PrettyItemDelegate.cpp" line="170"/>
         <source>%1 views</source>
         <translation>%1 переглядів</translation>
     </message>
@@ -862,53 +886,53 @@
 <context>
     <name>SearchView</name>
     <message>
-        <location filename="src/SearchView.cpp" line="74"/>
+        <location filename="src/SearchView.cpp" line="79"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
         <translation>Ласкаво просимо до &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="41"/>
+        <location filename="src/SearchView.cpp" line="46"/>
         <source>Get the full version</source>
         <translation>Отримати повнофункціональну версію</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="88"/>
+        <location filename="src/SearchView.cpp" line="93"/>
         <source>Enter</source>
         <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
         <translation>Введіть</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="93"/>
+        <location filename="src/SearchView.cpp" line="98"/>
         <source>a keyword</source>
         <translation>ключове слово</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="94"/>
+        <location filename="src/SearchView.cpp" line="99"/>
         <source>a channel</source>
         <translation>канал</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="99"/>
+        <location filename="src/SearchView.cpp" line="104"/>
         <source>to start watching videos.</source>
         <translation>, щоб почати дивитися відео.</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="124"/>
+        <location filename="src/SearchView.cpp" line="128"/>
         <source>Watch</source>
         <translation>Перегляд</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="142"/>
+        <location filename="src/SearchView.cpp" line="146"/>
         <source>Recent keywords</source>
         <translation>Останні ключові слова</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="160"/>
+        <location filename="src/SearchView.cpp" line="159"/>
         <source>Recent channels</source>
         <translation>Останні канали</translation>
     </message>
     <message>
-        <location filename="src/SearchView.h" line="34"/>
+        <location filename="src/SearchView.h" line="26"/>
         <source>Make yourself comfortable</source>
         <translation>Влаштовуйтеся зручніше</translation>
     </message>
