@@ -5,15 +5,17 @@
 #include <QtNetwork>
 #include <phonon/mediaobject.h>
 #include <phonon/videowidget.h>
+#include <phonon/seekslider.h>
 #include "View.h"
 #include "ListModel.h"
-#include "thlibrary/thblackbar.h"
+#include "segmentedcontrol.h"
 #include "searchparams.h"
 #include "playlistwidget.h"
 #include "loadingwidget.h"
 #include "videoareawidget.h"
 
 class DownloadItem;
+class PlaylistView;
 
 namespace The {
     QMap<QString, QAction*>* globalActions();
@@ -27,9 +29,7 @@ public:
     void initialize();
 
     // View
-    void appear() {
-        listView->setFocus();
-    }
+    void appear();
     void disappear();
     QMap<QString, QVariant> metadata() {
         QMap<QString, QVariant> metadata;
@@ -41,13 +41,14 @@ public:
     }
 
     void setMediaObject(Phonon::MediaObject *mediaObject);
-    void setSlider(QSlider *slider);
+    void setSlider(Phonon::SeekSlider *slider) { this->seekSlider = slider; }
 
 public slots:
     void search(SearchParams *searchParams);
     void pause();
     void stop();
     void skip();
+    void skipBackward();
     void skipVideo();
     void openWebPage();
     void copyWebPage();
@@ -76,6 +77,7 @@ private slots:
     void stateChanged(Phonon::State newState, Phonon::State oldState);
     void currentSourceChanged(const Phonon::MediaSource source);
     void showVideoContextMenu(QPoint point);
+    void aboutToFinish();
     // bar
     void searchMostRelevant();
     void searchMostRecent();
@@ -90,6 +92,7 @@ private slots:
     void downloadStatusChanged();
     void playbackFinished();
     void playbackResume();
+    void authorPushed(QModelIndex);
 
     /*
     void downloadProgress(int percent);
@@ -105,11 +108,11 @@ private:
     QSplitter *splitter;
 
     PlaylistWidget *playlistWidget;
-    QListView *listView;
+    PlaylistView *listView;
     ListModel *listModel;
 
     // sortBar
-    THBlackBar *sortBar;
+    SegmentedControl *sortBar;
     QAction *mostRelevantAction;
     QAction *mostRecentAction;
     QAction *mostViewedAction;
@@ -117,6 +120,7 @@ private:
     // phonon
     Phonon::MediaObject *mediaObject;
     Phonon::VideoWidget *videoWidget;
+    Phonon::SeekSlider *seekSlider;
 
     // loadingWidget
     VideoAreaWidget *videoAreaWidget;
@@ -134,7 +138,6 @@ private:
 #endif
 
     DownloadItem *downloadItem;
-    // QSlider *slider;
 
 };
 
