@@ -7,9 +7,6 @@
 #include "mac_startup.h"
 #include "macfullscreen.h"
 #endif
-#ifdef APP_WIN
-#include "local/win/qtwin.h"
-#endif
 #include "iconloader/qticonloader.h"
 
 int main(int argc, char **argv) {
@@ -19,17 +16,19 @@ int main(int argc, char **argv) {
 #endif
 
     QtSingleApplication app(argc, argv);
-    if (app.sendMessage("Wake up!"))
+    QString message = app.arguments().size() > 1 ? app.arguments().at(1) : "";
+    if (app.sendMessage(message))
         return 0;
 
     app.setApplicationName(Constants::NAME);
     app.setOrganizationName(Constants::ORG_NAME);
     app.setOrganizationDomain(Constants::ORG_DOMAIN);
-#ifndef APP_MAC
+#ifndef APP_WIN
     app.setWheelScrollLines(1);
 #endif
 
 #ifdef APP_MAC
+    app.setAttribute(Qt::AA_NativeWindows);
     QFile file(":/mac.css");
     file.open(QFile::ReadOnly);
     app.setStyleSheet(QLatin1String(file.readAll()));
@@ -69,6 +68,7 @@ int main(int argc, char **argv) {
     mainWin.setWindowTitle(Constants::NAME);
 
 #ifdef Q_WS_MAC
+    app.setQuitOnLastWindowClosed(false);
     mac::SetupFullScreenWindow(mainWin.winId());
 #endif
 
@@ -93,15 +93,12 @@ int main(int argc, char **argv) {
 #endif
 
 #ifdef APP_WIN
-    if (QtWin::isCompositionEnabled()) {
-        QtWin::extendFrameIntoClientArea(&mainWin);
-        mainWin.setContentsMargins(0, 0, 0, 0);
-    }
     app.setFont(QFont("Segoe UI", 9));
 #endif
 
     mainWin.show();
 
+    mainWin.connect(&app, SIGNAL(messageReceived(const QString &)), &mainWin, SLOT(messageReceived(const QString &)));
     app.setActivationWindow(&mainWin, true);
 
     // all string literals are UTF-8
